@@ -3,6 +3,8 @@ use quote::quote;
 use syn::{Expr, ExprBlock, ExprForLoop, Ident, Stmt};
 use syn_rsx::{Node, NodeType, ParserConfig};
 
+pub(crate) mod lookup;
+
 pub fn to_token_stream(input: proc_macro::TokenStream) -> TokenStream {
     match syn_rsx::parse_with_config(
         input,
@@ -31,17 +33,28 @@ fn node_to_tokens(node: Node) -> TokenStream {
 
     let children_tokens = children_to_tokens(node.children);
 
-    tokens.extend(quote! {{
-        #[allow(unused_braces)]
-        {
-            #children_tokens
-            if let Some(ns) = sauron::parser::tag_namespace(#name){
-                sauron::html::html_element_ns(#name, ns, vec![#(#attributes),*], children)
-            }else{
-                sauron::html::html_element(#name, vec![#(#attributes),*], children)
-            }
+    let self_closing = lookup::is_self_closing(&name);
+    let namespace = lookup::tag_namespace(&name);
+
+    tokens.extend(
+        if let Some(namespace) = namespace{
+            quote! {{
+                #[allow(unused_braces)]
+                {
+                    #children_tokens
+                    sauron::html::element_ns(Some(#namespace), #name, vec![#(#attributes),*], children, #self_closing)
+                }
+            }}
+        }else{
+            quote! {{
+                #[allow(unused_braces)]
+                {
+                    #children_tokens
+                    sauron::html::element_ns(None, #name, vec![#(#attributes),*], children, #self_closing)
+                }
+            }}
         }
-    }});
+    );
 
     tokens
 }
